Change Log
==========

`v2.0.4 <https://github.com/Chyroc/WechatSogou/tree/v2.0.4>`__ (2017-07-22)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/Chyroc/WechatSogou/compare/v2.0.3...v2.0.4>`__

**Closed issues:**

-  pip 安装 No module named requests 什么情况
   `#59 <https://github.com/Chyroc/WechatSogou/issues/59>`__
-  微信搜索公众号结果模版改变了
   `#51 <https://github.com/Chyroc/WechatSogou/issues/51>`__
-  ImportError: cannot import name config
   `#40 <https://github.com/Chyroc/WechatSogou/issues/40>`__

**Merged pull requests:**

-  Makefile tox `#74 <https://github.com/Chyroc/WechatSogou/pull/74>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  fix typo `#69 <https://github.com/Chyroc/WechatSogou/pull/69>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Add tools test
   `#68 <https://github.com/Chyroc/WechatSogou/pull/68>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  fix import and mv tools function
   `#67 <https://github.com/Chyroc/WechatSogou/pull/67>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  update package
   `#66 <https://github.com/Chyroc/WechatSogou/pull/66>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  add ci icon `#58 <https://github.com/Chyroc/WechatSogou/pull/58>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Add travis ci `#57 <https://github.com/Chyroc/WechatSogou/pull/57>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  release v2.0.3
   `#56 <https://github.com/Chyroc/WechatSogou/pull/56>`__
   (`Chyroc <https://github.com/Chyroc>`__)

`v2.0.3 <https://github.com/Chyroc/WechatSogou/tree/v2.0.3>`__ (2016-12-18)
---------------------------------------------------------------------------

**Closed issues:**

-  引入模块的时候报错
   `#33 <https://github.com/Chyroc/WechatSogou/issues/33>`__
-  导入文件后有bug
   `#31 <https://github.com/Chyroc/WechatSogou/issues/31>`__
-  请问如何设置代理
   `#27 <https://github.com/Chyroc/WechatSogou/issues/27>`__
-  请问最近搜狗返回的Html内容是改了吗？最近抓内容出错。
   `#25 <https://github.com/Chyroc/WechatSogou/issues/25>`__
-  结果模版更新了
   `#24 <https://github.com/Chyroc/WechatSogou/issues/24>`__
-  文章标题带引号（"，&quot）的情况解析报错
   `#23 <https://github.com/Chyroc/WechatSogou/issues/23>`__
-  请问，我运行test.py时为何没报错却没得到任何结果？
   `#21 <https://github.com/Chyroc/WechatSogou/issues/21>`__
-  如何获得公众号的id和名称？
   `#20 <https://github.com/Chyroc/WechatSogou/issues/20>`__
-  search\_gzh\_info无法取得内容
   `#18 <https://github.com/Chyroc/WechatSogou/issues/18>`__
-  原始文章url `#17 <https://github.com/Chyroc/WechatSogou/issues/17>`__
-  请问在Linux下可以使用吗？我运行了一下出现如下问题，还望指教
   `#16 <https://github.com/Chyroc/WechatSogou/issues/16>`__
-  log怎么使用？
   `#15 <https://github.com/Chyroc/WechatSogou/issues/15>`__
-  抓取数据有时成功，有时失败
   `#14 <https://github.com/Chyroc/WechatSogou/issues/14>`__
-  验证码打开失败问题原因是：
   `#13 <https://github.com/Chyroc/WechatSogou/issues/13>`__
-  验证码输入后失败
   `#12 <https://github.com/Chyroc/WechatSogou/issues/12>`__
-  获得的文章链接，如果打开需要验证码输入才跳转
   `#11 <https://github.com/Chyroc/WechatSogou/issues/11>`__
-  获取文章只能10篇？
   `#10 <https://github.com/Chyroc/WechatSogou/issues/10>`__
-  搜狗平台问题 `#9 <https://github.com/Chyroc/WechatSogou/issues/9>`__
-  deal\_article\_comment(text=text)并不能获得用户的评论内容
   `#8 <https://github.com/Chyroc/WechatSogou/issues/8>`__
-  py2.7 什么时候支持？
   `#7 <https://github.com/Chyroc/WechatSogou/issues/7>`__
-  PIL is not support Python3
   `#6 <https://github.com/Chyroc/WechatSogou/issues/6>`__
-  演示代码wechats.get\_gzh\_article\_by\_url\_dict(wechat\_info['url'])提示list
   index out of range
   `#5 <https://github.com/Chyroc/WechatSogou/issues/5>`__
-  如何使用代理 `#2 <https://github.com/Chyroc/WechatSogou/issues/2>`__
-  使用的是 python3 吗？
   `#1 <https://github.com/Chyroc/WechatSogou/issues/1>`__

**Merged pull requests:**

-  fix for ci `#50 <https://github.com/Chyroc/WechatSogou/pull/50>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  add readme.rst
   `#48 <https://github.com/Chyroc/WechatSogou/pull/48>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  添加安装说明 `#47 <https://github.com/Chyroc/WechatSogou/pull/47>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  upload to pypi
   `#46 <https://github.com/Chyroc/WechatSogou/pull/46>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  add `#45 <https://github.com/Chyroc/WechatSogou/pull/45>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Add/api test `#44 <https://github.com/Chyroc/WechatSogou/pull/44>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Fix/re ocr for get gzh article by url text
   `#43 <https://github.com/Chyroc/WechatSogou/pull/43>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  修复首页热门获取单页
   `#42 <https://github.com/Chyroc/WechatSogou/pull/42>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Fix/search article info
   `#41 <https://github.com/Chyroc/WechatSogou/pull/41>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Add/readme zanshu
   `#39 <https://github.com/Chyroc/WechatSogou/pull/39>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Fix/test ruokuai
   `#38 <https://github.com/Chyroc/WechatSogou/pull/38>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Feature/test ruokuai
   `#37 <https://github.com/Chyroc/WechatSogou/pull/37>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  Feature/update version
   `#35 <https://github.com/Chyroc/WechatSogou/pull/35>`__
   (`Chyroc <https://github.com/Chyroc>`__)
-  add requirements.txt
   `#34 <https://github.com/Chyroc/WechatSogou/pull/34>`__
   (`Chyroc <https://github.com/Chyroc>`__)

\* *This Change Log was automatically generated by
`github\_changelog\_generator <https://github.com/skywinder/Github-Changelog-Generator>`__*
